LiteFile class

Constructors

LiteFile({XFile? xFile, PlatformFile? platformFile, String? userSetName})

Properties

bytes → Uint8List?
no setter
hashCode → int
The hash code for this object.
no setteroverride
hasImageProvider → bool
no setter
height → int
no setter
isAudio → bool
no setter
isImage → bool
no setter
isSelected ↔ bool
Can be used to mark images in a multiselector
getter/setter pair
isVideo → bool
no setter
kiloBytes → FutureOr<int>
no setter
name → String
no setter
platformFile → PlatformFile?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userSetName → String?
when we rebuild LiteFile from xFile, xFile does not set name (seems like a bug in xFile) so this is used instead
final
width → int
no setter
xFile → XFile?
final

Methods

getBytesAsync() → Future<Uint8List?>
getMimeType([Uint8List? bytes]) → FutureOr<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMapAsync() → Future<Map>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(covariant LiteFile other) → bool
The equality operator.
override

Static Methods

fromBytesData({required List<int> bytes, required String name, String? mimeType}) → LiteFile
fromMapAsync(Map json) → Future<LiteFile>