LiteSearchField class

Inheritance

Constructors

LiteSearchField({Key? key, required ValueChanged<String> onSearch, TextEditingController? textEditingController, double paddingTop = 0.0, double paddingBottom = 0.0, double paddingLeft = 0.0, double paddingRight = 0.0, InputDecoration? decoration, FocusNode? focusNode, String? initialValue, String? hintText = 'Search...', bool autofocus = false, TextStyle? style, bool readOnly = false, LiteSearchFieldSettings settings = const LiteSearchFieldSettings()})
const

Properties

autofocus → bool
final
decoration → InputDecoration?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
initialValue → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSearch → ValueChanged<String>
final
paddingBottom → double
final
paddingLeft → double
final
paddingRight → double
final
paddingTop → double
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → LiteSearchFieldSettings
final
style → TextStyle?
final
textEditingController → TextEditingController?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<LiteSearchField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited