LiteSearchFieldSettings class

Constructors

LiteSearchFieldSettings({SearchTriggerType searchTriggerType = SearchTriggerType.automatic, int minSearchPhraseLength = 2, Duration searchDelay = const Duration(milliseconds: 800), Widget? searchIcon, LiteSearchFieldIconPosition iconPosition = LiteSearchFieldIconPosition.right})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconPosition → LiteSearchFieldIconPosition
final
minSearchPhraseLength → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchDelay → Duration
The delay after which a search will be triggered when user stops entering text. The recommended value is not less than 800 milliseconds
final
searchIcon → Widget?
final
searchTriggerType → SearchTriggerType
SearchTriggerType.automatic by default this means that the search will be triggered automatically after a user stops entering values and a searchDelay is passed
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited