LiteTimeout class

Inheritance

Constructors

LiteTimeout({Key? key, String pattern = 'mm:ss', required String name, String startedText = '', String notStartedText = '', TextAlign textAlign = TextAlign.center, TextStyle? style, bool autostart = true, double paddingTop = 0.0, double paddingBottom = 0.0, double paddingLeft = 0.0, double paddingRight = 0.0, int seconds = 10, TimeoutUpdate? onTimeoutUpdate, VoidCallback? onComplete})

Properties

autostart → bool
autostart whether the timer must start immediately or not if you pass false, then the timer has to be started manually by calling a shorthand of form('timerName').timer.start()
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
name → String
final
notStartedText → String
final
onComplete → VoidCallback?
final
onTimeoutUpdate → TimeoutUpdate?
final
paddingBottom → double
final
paddingLeft → double
final
paddingRight → double
final
paddingTop → double
final
pattern → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → int
final
startedText → String
final
style → TextStyle?
final
textAlign → TextAlign
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<LiteTimeout>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited