TreeMap class

Constructors

TreeMap({required TreeNode root, required Size size, Tile tile = const Squarify(), bool round = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
leaves → List<TreeNode>
no setter
root → TreeNode
final
round → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
final
tile → Tile
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited