TreeNodeOptions class

Constructors

TreeNodeOptions({Color? color, BoxBorder? border, Widget? child, GestureTapCallback? onTap})

Properties

border → BoxBorder?
final
child → Widget?
final
color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
onTap ↔ GestureTapCallback?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited