FormGroupField<T> class

Constructors

FormGroupField({required String name, required String? label})

Properties

error → String?
no setter
focusIndex → int
Sometimes it's necessary to know current field index to be able to focus next one, in case a field might lose focus for some time.
no setter
focusNode → FocusNode?
no setter
formName → String
no setter
hasContext → bool
no setter
hasError → bool
no setter
hasFocus → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isInitiallySet → bool
no setter
isMounted → bool
no setter
isRemoved → bool
no setter
label ↔ String?
getter/setter pair
name → String
final
preprocessor ↔ IPreprocessor?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textEditingController → TextEditingController?
no setter
value → Object?
no setter

Methods

clearDependencies() → void
getOrCreateFocusNode({FocusNode? focusNode}) → FocusNode?
getOrCreateTextEditingController({TextEditingController? controller}) → TextEditingController?
getSerializedValue() → Future<Object?>
getValue([bool applySerializer = false]) → Object?
mount([BuildContext? context]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(dynamic value, [bool isInitialValue = false, String? view]) → void
view is a String that will be displayed to a user. This must be null for text inputs since they are updated on user input but for other inputs e.g. a LiteDatePicker this must be a formatted date representation
requestFocus() → void
toString() → String
A string representation of this object.
inherited
unfocus({UnfocusDisposition disposition = UnfocusDisposition.scope}) → void
unmount() → void
updateValidatorsAndSerializer({required List<LiteValidator>? validators, required LiteFormValueSerializer? serializer}) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited