TimerData class

Constructors

TimerData({required String name, required bool autostart, required String groupName})

Properties

autostart ↔ bool
getter/setter pair
groupName → String
final
hashCode → int
The hash code for this object.
no setterinherited
isStarted → bool
no setter
keyName → String
no setter
name → String
final
numSeconds ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearTimer() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTimer() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited