FileDataReader class

Implemented types

Constructors

FileDataReader(String path)

Properties

hashCode → int
The hash code for this object.
no setterinherited
path ↔ String
The base path from which we will read data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String locale) → Future<String>
Read the locale data found for locale on our path.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited