UninitializedLocaleData<F> class

This is used as a marker for a locale data map that hasn't been initialized, and will throw an exception on any usage that isn't the fallback patterns/symbols provided.

Implemented types

Constructors

UninitializedLocaleData(String message, F fallbackData)

Properties

fallbackData → F
final
hashCode → int
The hash code for this object.
no setterinherited
keys → List<String>
no setter
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLocale(String localeName, Function findLocale) → void
override
containsKey(String key) → bool
findLocale(String? locale) → String
Given an initial locale or null, returns the locale that will be used for messages.
lookupMessage(String? messageText, String? locale, String? name, List<Object>? args, String? meaning, {MessageIfAbsent? ifAbsent}) → String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String key) → F

Static Properties

throwOnFallback → bool
If a message is looked up before any locale initialization, record it, and throw an exception with that information once the locale is initialized.
final