LocaleImplementation class

The primary implementation of the Locale interface.

Inheritance

Constructors

LocaleImplementation.unsafe(String languageCode, {String? scriptCode, String? countryCode, Iterable<String>? variants, LocaleExtensions? extensions})
Simple factory which assumes parameters are syntactically correct.
factory

Properties

countryCode → String?
The region subtag of the Locale Identifier, null if absent.
final
hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
The language subtag of the Locale Identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptCode → String?
The script subtag of the Locale Identifier, null if absent.
final
variants → Iterable<String>
Iterable of variant subtags, zero-length iterable if variants are absent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLanguageTag() → String
Returns the canonical Unicode BCP47 Locale Identifier for this locale.
override
toString() → String
Returns the canonical Unicode BCP47 Locale Identifier for this locale.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromSubtags({required String languageCode, String? scriptCode, String? countryCode}) → LocaleImplementation
Constructs a Locale instance that consists of only language, region and country subtags.
override