LocaleParser class

Constructors

LocaleParser(String localeId)
Parses Unicode CLDR Locale Identifiers.

Properties

hashCode → int
The hash code for this object.
no setterinherited
problems → List<String>
List of problems with the localeId the parser tried to parse.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptLanguage() → bool
Advances and returns true if current subtag is a language subtag.
acceptLowAlphaNumeric1to8() → bool
Advances and returns true if current subtag is alphanumeric, with length ranging from 1 to 8.
acceptLowAlphaNumeric2to8() → bool
Advances and returns true if current subtag is alphanumeric, with length ranging from 2 to 8.
acceptLowAlphaNumeric3to8() → bool
Advances and returns true if current subtag is alphanumeric, with length ranging from 3 to 8.
acceptRegion() → bool
Advances and returns true if current subtag is a region subtag.
acceptScript() → bool
Advances and returns true if current subtag is a script subtag.
acceptSingleton() → bool
Advances and returns true if current subtag is a singleton.
acceptTExtensionKey() → bool
Advances and returns true if current subtag is a valid T Extension key (tkey in the specification).
acceptUExtensionKey() → bool
Advances and returns true if current subtag is a valid U Extension key.
acceptVariants() → void
Advances, collecting subtags in _acceptedList, as long as the current subtag is a variant subtag.
advance() → void
Advance to the next subtag (see current and accepted).
atEnd() → bool
Returns true if all subtags have been parsed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processExtensions() → void
Consumes all remaining subtags, if syntactically valid.
processOtherExtensions(String singleton) → void
Consumes tags matched by other_extensions in the specification, except that the singleton in question must already be accepted and passed as parameter.
processPrivateUseExtensions() → void
Consumes tags matched by pu_extensions in the specification, except that the 'x' singleton must already be accepted.
processTExtensions() → void
Consumes tags matched by transformed_extensions in the specification, except that the 't' singleton must already be accepted.
processUExtensions() → void
Consumes tags matched by unicode_locale_extensions in the specification, except that the 'u' singleton must already be accepted.
toLocale() → LocaleImplementation?
Produces a Locale instance for the parser's current state.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

separators → RegExp
RegExp that matches Unicode Locale Identifier subtag separators.
final