PlatformFile class

Constructors

PlatformFile({String? path, required String name, required int size, Uint8List? bytes, Stream<List<int>>? readStream, String? identifier})
PlatformFile.fromMap(Map data, {Stream<List<int>>? readStream})
factory

Properties

bytes → Uint8List?
Byte data for this file. Particularly useful if you want to manipulate its data or easily upload to somewhere else. Check here in the FAQ an example on how to use it to upload on web.
final
extension → String?
File extension for this file.
no setter
hashCode → int
The hash code for this object.
no setteroverride
identifier → String?
The platform identifier for the original file, refers to an Uri on Android and to a NSURL on iOS. Is set to null on all other platforms since those are all already referencing the original file content.
final
name → String
File name including its extension.
final
path → String?
no setter
readStream → Stream<List<int>>?
File content as stream
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
The file size in bytes. Defaults to 0 if the file size could not be determined.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override