AgeDifference class

Constructors

AgeDifference({int years = 0, int months = 0, int days = 0})

Properties

days ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
months ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
years ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromNow(DateTime? anotherDate) → AgeDifference