LiteFormsConfiguration class

Constructors

LiteFormsConfiguration({LiteFormsTheme? lightTheme, LiteFormsTheme? darkTheme, AutovalidateMode? autovalidateMode, DropSelectorSettings dropSelectorSettings = const DropSelectorSettings(topLeftRadius: kDefaultFormSmoothRadius, topRightRadius: kDefaultFormSmoothRadius, bottomLeftRadius: kDefaultFormSmoothRadius, bottomRightRadius: kDefaultFormSmoothRadius, dropSelectorActionType: DropSelectorActionType.simple, dropSelectorType: DropSelectorType.adaptive), String? defaultDateFormat, TextEntryModalRouteSettings? defaultTextEntryModalRouteSettings, String? defaultTimeFormat, bool? allowUnfocusOnTapOutside, bool useAutogeneratedHints = false})
LiteFormsConfiguration.thinFields(BuildContext context)
factory
LiteFormsConfiguration.vanila(BuildContext context)
LiteFormsConfiguration.vanila is a default preset which you can use as a starting point
factory

Properties

activeTheme → LiteFormsTheme?
no setter
allowUnfocusOnTapOutside → bool?
Will automatically hide the keyboard if you tap outside of the focused text input. This can also be set individually for each form via a LiteFormGroup constructor Has no effect on web
final
autovalidateMode → AutovalidateMode?
final
darkTheme → LiteFormsTheme?
final
defaultDateFormat → String?
final
defaultTextEntryModalRouteSettings → TextEntryModalRouteSettings?
a default settings for text entry using TextEntryType.onModalRoute
final
defaultTextStyle → TextStyle?
no setter
defaultTimeFormat → String?
final
destructiveColor → Color?
no setter
dropSelectorChipColor → Color?
no setter
dropSelectorSettings → DropSelectorSettings
final
filePickerDecoration → BoxDecoration?
no setter
hashCode → int
The hash code for this object.
no setterinherited
inputDecoration → InputDecoration?
no setter
lightTheme → LiteFormsTheme?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
no setter
useAutogeneratedHints → bool
if this is true and you don't pass hintText to a form field, it will automatically generate it based on the field's name value, using splitByCamelCase method()
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited