LiteFormsTheme class

Constructors

LiteFormsTheme({required TextStyle defaultTextStyle, InputDecoration? inputDecoration, Color? shadowColor, Color? dropSelectorChipColor, BoxDecoration? filePickerDecoration, Color? destructiveColor})
const

Properties

defaultTextStyle → TextStyle
final
destructiveColor → Color?
final
dropSelectorChipColor → Color?
final
filePickerDecoration → BoxDecoration?
final
hashCode → int
The hash code for this object.
no setterinherited
inputDecoration → InputDecoration?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited