StringExtensions extension

on

Properties

isNullOrWhiteSpace → bool

Available on String, provided by the StringExtensions extension

no setter
lastLetter → String

Available on String, provided by the StringExtensions extension

no setter

Methods

base64ToMap() → Map

Available on String, provided by the StringExtensions extension

copyToClipBoard() → Future

Available on String, provided by the StringExtensions extension

copyToClipboard() → Future

Available on String, provided by the StringExtensions extension

firstToLowerCase() → String

Available on String, provided by the StringExtensions extension

firstToUpperCase() → String

Available on String, provided by the StringExtensions extension

isIgnoredInForm() → bool

Available on String, provided by the StringExtensions extension

isMatchingSearch(String? searchFor) → bool

Available on String, provided by the StringExtensions extension

splitByCamelCase() → String

Available on String, provided by the StringExtensions extension

splitBySpace() → List<String>

Available on String, provided by the StringExtensions extension

toCamelCase([bool firstToUpper = true]) → String

Available on String, provided by the StringExtensions extension

toDoubleAmount() → double

Available on String, provided by the StringExtensions extension

toFormIgnoreName() → String

Available on String, provided by the StringExtensions extension

this is a utility method. Call it on a FormGroupField's name value, to exclude this form field value from a form. This might be necessary sometimes, for example if you want to combine a few form fields in one (e.g. a LitePhoneInputField) but you want only one of them in a form