utils/value_serializer library

Classes

LiteSerializers
LiteSerializers is a set of built-in serializers that can be used to simplify a work with some types of values

Functions

nonConvertingValueConvertor(Object? value) → Object?
The default for all fields. This means that the values is supposed to be accepted as is. If you need to convert the value somehow, write your custom serializer for a particular field

Typedefs

LiteFormValueDeserializer = Object? Function(dynamic value)
LiteFormValueSerializer = FutureOr<Object?> Function(dynamic value)
used to write custom value serializers / deserializers