LiteSerializers class

LiteSerializers is a set of built-in serializers that can be used to simplify a work with some types of values

Constructors

LiteSerializers()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

filesToMapList(Object? value) → FutureOr<Object?>
fullPhoneDataWithCountry(Object? value) → Map?
phoneDataToFormattedString(Object? value) → String?
phoneDataToUnformattedString(Object? value) → String?
toDouble(Object? value) → double
toDouble assumes that the input is numeric or it is a string that has a numeric format and tries to convert it to a double value
toInt(Object? value) → int